# digitalmarketplace-test-utils

![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)

Utility functions and scripts for testing Digital Marketplace code

This library's dependencies are deliberately kept minimal - see comment in `setup.py` before
adding any more!

## Licence

Unless stated otherwise, the codebase is released under [the MIT License][mit].
This covers both the codebase and any sample code in the documentation.

The documentation is [&copy; Crown copyright][copyright] and available under the terms
of the [Open Government 3.0][ogl] licence.

[mit]: LICENCE
[copyright]: http://www.nationalarchives.gov.uk/information-management/re-using-public-sector-information/uk-government-licensing-framework/crown-copyright/
[ogl]: http://www.nationalarchives.gov.uk/doc/open-government-licence/version/3/
